/**
  *  \file server/config.cc
  */

#include <fstream>
#include <stdlib.h>
#include <ctype.h>
#include "server/config.h"
#include "cpluslib/types.h"

void
loadConfiguration(void func(string_t key, string_t value), bool allowCurrent)
{
    /* Locate config file */
    const char* fn = getenv("C2CONFIG");
    if (!fn) {
        if (!allowCurrent) {
            return;
        }
        fn = "c2config.txt";
    }

    /* Open config file */
    std::ifstream file(fn);
    if (!file) {
        perror(fn);
        return;
    }

    /* Read it */
    string_t line;
    while (getline(file, line)) {
        string_t::size_type i = line.find_first_of("#=");
        if (i != line.npos && line[i] == '=') {
            string_t key(strTrim(string_t(line, 0, i)));
            string_t value(strTrim(string_t(line, i+1)));
            for (string_t::size_type i = 0; i < key.size(); ++i)
                key[i] = toupper(static_cast<uint8_t>(key[i]));
            func(key, value);
        }
    }
}

bool
isTrue(string_t value)
{
    return value.size() > 0
        && (value[0] == 'y'
            || value[0] == 'Y'
            || value[0] == '1');
}
